@@ -1,4 +1,4 @@
-from typing import Iterator, List, Union, cast
+from typing import Iterator, Sequence, Union, cast
 
 from cognite.client._api_client import APIClient
 from cognite.client.data_classes import LabelDefinition, LabelDefinitionFilter, LabelDefinitionList
@@ -24,8 +24,8 @@ class LabelsAPI(APIClient):
         external_id_prefix: str = None,
         limit: int = None,
         chunk_size: int = None,
-        data_set_ids: List[int] = None,
-        data_set_external_ids: List[str] = None,
+        data_set_ids: Sequence[int] = None,
+        data_set_external_ids: Sequence[str] = None,
     ) -> Union[Iterator[LabelDefinition], Iterator[LabelDefinitionList]]:
         data_set_ids_processed = None
         if data_set_ids or data_set_external_ids:
@@ -46,16 +46,16 @@ class LabelsAPI(APIClient):
         self,
         name: str = None,
         external_id_prefix: str = None,
-        data_set_ids: List[int] = None,
-        data_set_external_ids: List[str] = None,
+        data_set_ids: Sequence[int] = None,
+        data_set_external_ids: Sequence[str] = None,
         limit: int = 25,
     ) -> LabelDefinitionList:
         """`List Labels <https://docs.cognite.com/api/v1/#operation/listLabels>`_
 
         Args:
             name (str): returns the label definitions matching that name
-            data_set_ids (List[int]): return only labels in the data sets with these ids.
-            data_set_external_ids (List[str]): return only labels in the data sets with these external ids.
+            data_set_ids (Sequence[int]): return only labels in the data sets with these ids.
+            data_set_external_ids (Sequence[str]): return only labels in the data sets with these external ids.
             external_id_prefix (str): filter label definitions with external ids starting with the prefix specified
             limit (int, optional): Maximum number of label definitions to return.
 
@@ -95,15 +95,15 @@ class LabelsAPI(APIClient):
         )
 
     def create(
-        self, label: Union[LabelDefinition, List[LabelDefinition]]
+        self, label: Union[LabelDefinition, Sequence[LabelDefinition]]
     ) -> Union[LabelDefinition, LabelDefinitionList]:
         """`Create one or more label definitions. <https://docs.cognite.com/api/v1/#operation/createLabelDefinitions>`_
 
         Args:
-            Label (Union[LabelDefinition, List[LabelDefinition]]): label definition or a list of label definitions to create.
+            Label (Union[LabelDefinition, Sequence[LabelDefinition]]): label definition or a list of label definitions to create.
 
         Returns:
-            Union[LabelDefinition, List[LabelDefinition]]: Created label definition(s)
+            Union[LabelDefinition, LabelDefinitionList]: Created label definition(s)
 
         Examples:
 
@@ -115,18 +115,18 @@ class LabelsAPI(APIClient):
                 >>> labels = [LabelDefinition(external_id="ROTATING_EQUIPMENT", name="Rotating equipment"), LabelDefinition(external_id="PUMP", name="pump")]
                 >>> res = c.labels.create(labels)
         """
-        if isinstance(label, list):
+        if isinstance(label, Sequence):
             if len(label) > 0 and not isinstance(label[0], LabelDefinition):
-                raise TypeError("'label' must be of type List[LabelDefinition]")
+                raise TypeError("'label' must be of type LabelDefinition or Sequence[LabelDefinition]")
         elif not isinstance(label, LabelDefinition):
-            raise TypeError("'label' must be of type LabelDefinition")
+            raise TypeError("'label' must be of type LabelDefinition or Sequence[LabelDefinition]")
         return self._create_multiple(list_cls=LabelDefinitionList, resource_cls=LabelDefinition, items=label)
 
-    def delete(self, external_id: Union[str, List[str]] = None) -> None:
+    def delete(self, external_id: Union[str, Sequence[str]] = None) -> None:
         """`Delete one or more label definitions <https://docs.cognite.com/api/v1/#operation/deleteLabels>`_
 
         Args:
-            external_id (Union[str, List[str]]): One or more label external ids
+            external_id (Union[str, Sequence[str]]): One or more label external ids
 
         Returns:
             None
